from setuptools import setup
setup(
    name="validate_adhar",
    version="1.0.1",
    description='This Package is a Function to validate Adhaar Car and name',
    author='Oswald Fernandes',
    author_email='oswfernand@yahoo.com',
    packages=['validate_adhar']
)